import { Component, OnInit } from '@angular/core';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {NzModalService} from 'ng-zorro-antd';
import {CompanyService} from '../../../services/company.service';
import {CommonsService} from '../../../services/commons.service';
import {ActivatedRoute, Params, Router} from '@angular/router';

@Component({
  selector: 'app-company-update',
  templateUrl: './company-update.component.html',
  styleUrls: ['./company-update.component.scss']
})
export class CompanyUpdateComponent implements OnInit {

  companyForm: FormGroup;
  btnLoading = false;
  provinceArray = [];

  dataObject: any = {};


  constructor(private form: FormBuilder,
              private modal: NzModalService,
              private companyService: CompanyService,
              private commonsService: CommonsService,
              private activatedRoute: ActivatedRoute,
              private router: Router) { }

  ngOnInit(): void {
    this.commonsService.getProvinceList(data => {
      this.provinceArray = data['return_data'];
    });

    this.activatedRoute.queryParams.subscribe((queryParams: Params) => {
      if (queryParams['companyId'] != null && queryParams['companyId'].length > 0) {
        this.companyService.companyView(queryParams['companyId'], data => {
          if (data['return_code'] === '000000') {
            this.dataObject = data['return_data']['company'];
            this.dataObject['loginName'] = data['return_data']['user']['loginName'];
            this.dataObject['password'] = data['return_data']['user']['password'];
            this.companyForm.patchValue(this.dataObject);
          }
        });
      }
    });
    this.companyForm = this.form.group({
      regionId: [null, [Validators.required]],
      name: [null, [Validators.required]],
      loginName: [{ value: null, disabled: true}],
      address: [null],
      phone: [null],
    });
  }

  submitFrom() {
    this.btnLoading = true;
    for (const i in this.companyForm.controls) {
      this.companyForm.controls[i].markAsDirty();
      this.companyForm.controls[i].updateValueAndValidity();
    }
    if (this.companyForm.status == null || this.companyForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请规范填写所有的必填项信息',
      });
      this.btnLoading = false;
      return;
    }
    this.companyForm.value['companyId'] = this.dataObject['id'];
    this.companyService.updateCompany(this.companyForm.value, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '修改成功',
          nzOnOk: () => this.router.navigateByUrl('admin/company/list')
        });
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
      this.btnLoading = false;
    });
  }

}
