import { Component, OnInit } from '@angular/core';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {CommonsService} from '../../../services/commons.service';
import {LocalStorageService} from '../../../services/local-storage.service';
import {FormBuilder, FormGroup} from '@angular/forms';
import {DeviceOrderService} from '../../../services/device-order.service';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';
import {environment} from '../../../../environments/environment';

@Component({
  selector: 'app-device-order-list',
  templateUrl: './device-order-list.component.html',
  styleUrls: ['./device-order-list.component.scss']
})
export class DeviceOrderListComponent implements OnInit {
// 角色类型 0：超级管理员  1：公司  2：代理商  3：业务员  4：商户  5：门店
  roleType: number;

  baseUrl = environment.baseUrl;

  loadingObject = {
    spinning: false,
    msg: '加载中'
  };

  dataObject: any = {};
  tableLoading = true;
  searchForm: FormGroup;
  pageNum: number;
  whereObject: any = {};
  isCollapse = false;
  deviceOrderStatusArray = [];
  deviceOrderTypeArray = [];
  deviceTypeArray = [];
  deviceListModal = false;
  orderAssignList = [];

  constructor(private modal: NzModalService,
              private message: NzMessageService,
              private commonsService: CommonsService,
              private deviceOrderService: DeviceOrderService,
              private store: LocalStorageService,
              private form: FormBuilder) { }

  ngOnInit(): void {
    this.roleType = this.store.get(ADMIN_INFO_OBJECT)['secRole'].roleType;

    this.searchForm = this.form.group({
      companyName: [null],
      agentName: [null],
      salesmanName: [null],
      merName: [null],
      storeName: [null],
      orderNo: [null],
      orderType: [null],
      deviceType: [null],
      status: [null],
    });

    this.commonsService.getDictionary('DEVICE_ORDER_TYPE', data => {
      this.deviceOrderTypeArray = data['return_data'];
    });

    this.commonsService.getDictionary('DEVICE_ORDER_STATUS', data => {
      this.deviceOrderStatusArray = data['return_data'];
    });

    this.commonsService.getDictionary('DEVICE_TYPE', data => {
      this.deviceTypeArray = data['return_data'];
    });

    this.requestData(1);
  }

  toggleCollapse(): void {
    this.isCollapse = !this.isCollapse;
  }

  /**
   * 请求数据
   */
  requestData(pageNum) {
    this.tableLoading = true;
    this.whereObject['pageNum'] = pageNum;
    this.whereObject['pageSize'] = 10;
    this.deviceOrderService.getOrderList(this.whereObject, data => {
      if (data['return_code'] === '000000') {
        this.dataObject = data['return_data'];
      } else {
        this.modal.error(data['return_msg']);
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    this.whereObject = whereObject;
    this.requestData(1);
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }

  /**
   * 展示设备列表模态框
   */
  showDeviceListModal(dataList: []) {
    this.orderAssignList = dataList;
    this.deviceListModal = true;
  }

  /**
   * 关闭设备列表模态框
   */
  closeDeviceListModal() {
    this.orderAssignList = [];
    this.deviceListModal = false;
  }
}
